Index: include/core/SkTextBlob.h |
diff --git a/include/core/SkTextBlob.h b/include/core/SkTextBlob.h |
index 334cfb98c4595d2d51844e55c82880b89de9a34e..1f04d3891278e42ae24452f21ecc57a428119426 100644 |
--- a/include/core/SkTextBlob.h |
+++ b/include/core/SkTextBlob.h |
@@ -23,7 +23,7 @@ class SkWriteBuffer; |
class SK_API SkTextBlob : public SkRefCnt { |
public: |
/** |
* Returns the blob bounding box. |
*/ |
const SkRect& bounds() const { return fBounds; } |
@@ -188,6 +188,9 @@ private: |
int count, SkPoint offset); |
void updateDeferredBounds(); |
+ static SkRect ConservativeRunBounds(const SkTextBlob::RunRecord&); |
+ static SkRect TightRunBounds(const SkTextBlob::RunRecord&); |
+ |
SkAutoTMalloc<uint8_t> fStorage; |
size_t fStorageSize; |
size_t fStorageUsed; |
@@ -23,7 +23,7 @@ class SkWriteBuffer; |
public: |
/** |
- * Returns the blob bounding box. |
+ * Returns a conservative blob bounding box. |
*/ |
const SkRect& bounds() const { return fBounds; } |